Files in this directory and its subdirectories are Copyright (c) Kx Systems and distributed under [Apache License 2.0](LICENSE). 


Original files can be found in the Kx Systems' [kdb repository](https://github.com/KxSystems/kdb): 

* [k.h](https://github.com/KxSystems/kdb/blob/master/c/c/k.h) 
* [w32/q.lib](https://github.com/KxSystems/kdb/blob/master/w32/q.lib) 
* [w64/q.lib](https://github.com/KxSystems/kdb/blob/master/w64/q.lib) 
